<?php

declare(strict_types=1);

namespace Drupal\Tests\views_bulk_operations\Functional\Update;

use Drupal\FunctionalTests\Update\UpdatePathTestBase;

/**
 * Tests database updates to the views_bulk_operations module.
 *
 * @group Update
 * @group views_bulk_operations
 */
class VboUpdateHookTest extends UpdatePathTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setDatabaseDumpFiles(): void {
    $this->databaseDumpFiles = [
      $this->root . '/core/modules/system/tests/fixtures/update/drupal-10.3.0.filled.standard.php.gz',
      __DIR__ . '/../../../fixtures/update/views_bulk_operations-8035.php',
    ];
  }

  /**
   * Test that the update hook to fix force_selection_info configuration works.
   */
  public function testUpdateHook8036(): void {
    // Setup: Look at the schema version.
    $this->assertEquals(8035, $this->getSchemaVersion('views_bulk_operations'));

    // Assert: Before the update hook runs, the first view should have
    // 'force_selection_info' set to '0' and the second view should have
    // 'force_selection_info' set to '1'.
    $this->assertSame('0', $this->config('views.view.views_bulk_operations_test_1')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.force_selection_info')
    );
    $this->assertSame('1', $this->config('views.view.views_bulk_operations_test_2')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.force_selection_info')
    );

    // System under test: Run updates.
    $this->runUpdates();

    // Assert: Check that the schema version has changed.
    $this->assertEquals(8036, $this->getSchemaVersion('views_bulk_operations'));

    // Assert: After the update hook runs, the first view should have
    // 'show_multipage_selection_box' and 'show_select_all' set to 'default'; and
    // the second view should have 'show_multipage_selection_box'  and
    // 'show_select_all' set to 'show'.
    $this->assertSame('default', $this->config('views.view.views_bulk_operations_test_1')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.show_multipage_selection_box')
    );
    $this->assertSame('default', $this->config('views.view.views_bulk_operations_test_1')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.show_select_all')
    );
    $this->assertSame('show', $this->config('views.view.views_bulk_operations_test_2')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.show_multipage_selection_box')
    );
    $this->assertSame('show', $this->config('views.view.views_bulk_operations_test_2')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.show_select_all')
    );

    // Assert: After the update hook runs, neither view should have a
    // 'force_selection_info' key anymore.
    $this->assertNull($this->config('views.view.views_bulk_operations_test_2')
      ->get('display.default.display_options.fields.views_bulk_operations_bulk_form.force_selection_info')
    );
  }

  /**
   * Get the installed schema version of a module.
   *
   * @param string $module
   *   The module to get the installed schema version of.
   *
   * @return int|null
   *   The schema version of the given module.
   */
  protected function getSchemaVersion(string $module): ?int {
    return $this->container->get('update.update_hook_registry')->getInstalledVersion($module);
  }

}
